Kamzik3 is Controlling Framework with unified Graphical Interface.

Requirements
------------

  * Python: 3.6 or 3.7

  **Python Modules: Backend**

  * numpy
  * pyzmq
  * pint
  * bidict
  * pyqt5
  * pyqtgraph
  * pyserial
  * oyaml

  **Python Modules: Optional**

  * pytango
  * pyopengl
  * sysutil
  * pydaqmx
